[gimp/goat-invasion: 464/608] app: rename TempBuf to GimpTempBuf
- From: Michael Natterer <mitch src gnome org>
- To: commits-list gnome org
- Cc:
- Subject: [gimp/goat-invasion: 464/608] app: rename TempBuf to GimpTempBuf
- Date: Fri, 27 Apr 2012 21:04:23 +0000 (UTC)
commit 62bfa8c52af6a55e2cbe49fe8294d78ac0ce4f37
Author: Michael Natterer <mitch gimp org>
Date: Sun Apr 8 20:25:49 2012 +0200
app: rename TempBuf to GimpTempBuf
app/base/base-types.h | 2 +-
app/base/pixel-region.c | 2 +-
app/base/pixel-region.h | 2 +-
app/base/temp-buf.c | 48 +++++-----
app/base/temp-buf.h | 36 +++---
app/base/tile-manager-preview.c | 22 ++--
app/base/tile-manager-preview.h | 20 ++--
app/core/gimpbrush-boundary.c | 4 +-
app/core/gimpbrush-transform.c | 20 ++--
app/core/gimpbrush-transform.h | 44 ++++----
app/core/gimpbrush.c | 50 +++++-----
app/core/gimpbrush.h | 16 ++--
app/core/gimpbrushgenerated.c | 10 +-
app/core/gimpbuffer.c | 58 +++++-----
app/core/gimpcurve.c | 4 +-
app/core/gimpdrawable-combine.c | 2 +-
app/core/gimpdrawable-preview.c | 40 ++++----
app/core/gimpdrawable-preview.h | 24 ++--
app/core/gimpgradient.c | 6 +-
app/core/gimpimage-preview.c | 6 +-
app/core/gimpimage-preview.h | 40 ++++----
app/core/gimpimage-private.h | 2 +-
app/core/gimppalette.c | 6 +-
app/core/gimppattern.c | 8 +-
app/core/gimppattern.h | 16 ++--
app/core/gimppreviewcache.c | 50 +++++-----
app/core/gimppreviewcache.h | 16 ++--
app/core/gimpundo.c | 70 ++++++------
app/core/gimpundo.h | 2 +-
app/core/gimpviewable.c | 34 +++---
app/core/gimpviewable.h | 10 +-
app/gegl/gimp-gegl-utils.c | 2 +-
app/gegl/gimp-gegl-utils.h | 2 +-
app/paint/gimpbrushcore.c | 177 +++++++++++++++++---------------
app/paint/gimpbrushcore.h | 48 +++++-----
app/paint/gimpconvolve.c | 2 +-
app/paint/gimpheal.c | 4 +-
app/paint/gimpink.c | 4 +-
app/paint/gimppaintbrush.c | 2 +-
app/paint/gimpsmudge.c | 14 ++--
app/pdb/drawable-cmds.c | 10 +-
app/pdb/image-cmds.c | 4 +-
app/text/gimpfont.c | 48 +++++-----
app/tools/gimpiscissorstool.c | 8 +-
app/tools/gimpiscissorstool.h | 2 +-
app/vectors/gimpvectors-preview.c | 4 +-
app/vectors/gimpvectors-preview.h | 8 +-
app/widgets/gimpviewrenderer.c | 10 +-
app/widgets/gimpviewrenderer.h | 4 +-
app/widgets/gimpviewrendererbrush.c | 4 +-
app/widgets/gimpviewrendererbuffer.c | 14 ++--
app/widgets/gimpviewrendererdrawable.c | 4 +-
app/widgets/gimpviewrendererimage.c | 16 ++--
tools/pdbgen/pdb/drawable.pdb | 10 +-
tools/pdbgen/pdb/image.pdb | 4 +-
55 files changed, 541 insertions(+), 534 deletions(-)
---
diff --git a/app/base/base-types.h b/app/base/base-types.h
index e97c9d9..d5580de 100644
--- a/app/base/base-types.h
+++ b/app/base/base-types.h
@@ -53,7 +53,7 @@ typedef struct _PixelRegionHolder PixelRegionHolder;
typedef struct _SioxState SioxState;
-typedef struct _TempBuf TempBuf;
+typedef struct _GimpTempBuf GimpTempBuf;
typedef struct _Tile Tile;
typedef struct _TileManager TileManager;
diff --git a/app/base/pixel-region.c b/app/base/pixel-region.c
index bf43053..95c1054 100644
--- a/app/base/pixel-region.c
+++ b/app/base/pixel-region.c
@@ -84,7 +84,7 @@ pixel_region_init (PixelRegion *PR,
void
pixel_region_init_temp_buf (PixelRegion *PR,
- TempBuf *temp_buf,
+ GimpTempBuf *temp_buf,
gint x,
gint y,
gint w,
diff --git a/app/base/pixel-region.h b/app/base/pixel-region.h
index 89b8491..22ea94d 100644
--- a/app/base/pixel-region.h
+++ b/app/base/pixel-region.h
@@ -66,7 +66,7 @@ void pixel_region_init (PixelRegion *PR,
gint h,
gboolean dirty);
void pixel_region_init_temp_buf (PixelRegion *PR,
- TempBuf *temp_buf,
+ GimpTempBuf *temp_buf,
gint x,
gint y,
gint w,
diff --git a/app/base/temp-buf.h b/app/base/temp-buf.h
index decea08..80c1c59 100644
--- a/app/base/temp-buf.h
+++ b/app/base/temp-buf.h
@@ -19,7 +19,7 @@
#define __TEMP_BUF_H__
-struct _TempBuf
+struct _GimpTempBuf
{
const Babl *format; /* pixel format */
gint width;
@@ -32,27 +32,27 @@ struct _TempBuf
/* The temp buffer functions */
-TempBuf * temp_buf_new (gint width,
- gint height,
- const Babl *fomat);
-TempBuf * temp_buf_copy (TempBuf *src);
-TempBuf * temp_buf_scale (TempBuf *buf,
- gint width,
- gint height) G_GNUC_WARN_UNUSED_RESULT;
+GimpTempBuf * temp_buf_new (gint width,
+ gint height,
+ const Babl *fomat);
+GimpTempBuf * temp_buf_copy (GimpTempBuf *src);
+GimpTempBuf * temp_buf_scale (GimpTempBuf *buf,
+ gint width,
+ gint height) G_GNUC_WARN_UNUSED_RESULT;
-void temp_buf_demultiply (TempBuf *buf);
+void temp_buf_demultiply (GimpTempBuf *buf);
-void temp_buf_free (TempBuf *buf);
-guchar * temp_buf_get_data (const TempBuf *buf);
-gsize temp_buf_get_data_size (TempBuf *buf);
-guchar * temp_buf_data_clear (TempBuf *buf);
+void temp_buf_free (GimpTempBuf *buf);
+guchar * temp_buf_get_data (const GimpTempBuf *buf);
+gsize temp_buf_get_data_size (GimpTempBuf *buf);
+guchar * temp_buf_data_clear (GimpTempBuf *buf);
-gsize temp_buf_get_memsize (TempBuf *buf);
-void temp_buf_dump (TempBuf *buf,
- const gchar *filename);
+gsize temp_buf_get_memsize (GimpTempBuf *buf);
+void temp_buf_dump (GimpTempBuf *buf,
+ const gchar *filename);
-GeglBuffer * gimp_temp_buf_create_buffer (TempBuf *temp_buf,
- gboolean take_ownership);
+GeglBuffer * gimp_temp_buf_create_buffer (GimpTempBuf *temp_buf,
+ gboolean take_ownership);
#endif /* __TEMP_BUF_H__ */
diff --git a/app/base/tile-manager-preview.c b/app/base/tile-manager-preview.c
index e699003..28f9459 100644
--- a/app/base/tile-manager-preview.c
+++ b/app/base/tile-manager-preview.c
@@ -31,16 +31,16 @@
#include "tile-manager-preview.h"
-static TempBuf * tile_manager_create_preview (TileManager *tiles,
- gint src_x,
- gint src_y,
- gint src_width,
- gint src_height,
- gint dest_width,
- gint dest_height);
+static GimpTempBuf * tile_manager_create_preview (TileManager *tiles,
+ gint src_x,
+ gint src_y,
+ gint src_width,
+ gint src_height,
+ gint dest_width,
+ gint dest_height);
-TempBuf *
+GimpTempBuf *
tile_manager_get_preview (TileManager *tiles,
gint width,
gint height)
@@ -55,7 +55,7 @@ tile_manager_get_preview (TileManager *tiles,
width, height);
}
-TempBuf *
+GimpTempBuf *
tile_manager_get_sub_preview (TileManager *tiles,
gint src_x,
gint src_y,
@@ -84,7 +84,7 @@ tile_manager_get_sub_preview (TileManager *tiles,
dest_width, dest_height);
}
-static TempBuf *
+static GimpTempBuf *
tile_manager_create_preview (TileManager *tiles,
gint src_x,
gint src_y,
@@ -93,7 +93,7 @@ tile_manager_create_preview (TileManager *tiles,
gint dest_width,
gint dest_height)
{
- TempBuf *preview;
+ GimpTempBuf *preview;
PixelRegion srcPR;
PixelRegion destPR;
gint subsample = 1;
diff --git a/app/base/tile-manager-preview.h b/app/base/tile-manager-preview.h
index 78275fd..8d784cf 100644
--- a/app/base/tile-manager-preview.h
+++ b/app/base/tile-manager-preview.h
@@ -19,16 +19,16 @@
#define __TILE_MANAGER_PREVIEW_H__
-TempBuf * tile_manager_get_preview (TileManager *tiles,
- gint width,
- gint height);
-TempBuf * tile_manager_get_sub_preview (TileManager *tiles,
- gint src_x,
- gint src_y,
- gint src_width,
- gint src_height,
- gint dest_width,
- gint dest_height);
+GimpTempBuf * tile_manager_get_preview (TileManager *tiles,
+ gint width,
+ gint height);
+GimpTempBuf * tile_manager_get_sub_preview (TileManager *tiles,
+ gint src_x,
+ gint src_y,
+ gint src_width,
+ gint src_height,
+ gint dest_width,
+ gint dest_height);
#endif /* __TILE_MANAGER_PREVIEW_H__ */
diff --git a/app/core/gimpbrush-boundary.c b/app/core/gimpbrush-boundary.c
index 14fe9e8..2be0450 100644
--- a/app/core/gimpbrush-boundary.c
+++ b/app/core/gimpbrush-boundary.c
@@ -37,7 +37,7 @@ gimp_brush_transform_boundary_exact (GimpBrush *brush,
gdouble angle,
gdouble hardness)
{
- const TempBuf *mask;
+ const GimpTempBuf *mask;
mask = gimp_brush_transform_mask (brush,
scale, aspect_ratio, angle, hardness);
@@ -48,7 +48,7 @@ gimp_brush_transform_boundary_exact (GimpBrush *brush,
GimpBoundSeg *bound_segs;
gint n_bound_segs;
- buffer = gimp_temp_buf_create_buffer ((TempBuf *) mask, FALSE);
+ buffer = gimp_temp_buf_create_buffer ((GimpTempBuf *) mask, FALSE);
bound_segs = gimp_boundary_find (buffer, NULL,
GIMP_BOUNDARY_WITHIN_BOUNDS,
diff --git a/app/core/gimpbrush-transform.c b/app/core/gimpbrush-transform.c
index 95843d5..2091cf8 100644
--- a/app/core/gimpbrush-transform.c
+++ b/app/core/gimpbrush-transform.c
@@ -39,7 +39,7 @@
/* local function prototypes */
-static void gimp_brush_transform_bounding_box (TempBuf *brush,
+static void gimp_brush_transform_bounding_box (GimpTempBuf *brush,
const GimpMatrix3 *matrix,
gint *x,
gint *y,
@@ -100,15 +100,15 @@ gimp_brush_real_transform_size (GimpBrush *brush,
* Some variables end with the suffix _i to indicate they have been
* premultiplied by int_multiple
*/
-TempBuf *
+GimpTempBuf *
gimp_brush_real_transform_mask (GimpBrush *brush,
gdouble scale,
gdouble aspect_ratio,
gdouble angle,
gdouble hardness)
{
- TempBuf *result;
- TempBuf *source;
+ GimpTempBuf *result;
+ GimpTempBuf *source;
guchar *dest;
const guchar *src;
GimpMatrix3 matrix;
@@ -328,7 +328,7 @@ gimp_brush_real_transform_mask (GimpBrush *brush,
if (hardness < 1.0)
{
- TempBuf *blur_src;
+ GimpTempBuf *blur_src;
GeglBuffer *src_buffer;
GeglBuffer *dest_buffer;
gint kernel_size =
@@ -395,15 +395,15 @@ gimp_brush_real_transform_mask (GimpBrush *brush,
* Some variables end with the suffix _i to indicate they have been
* premultiplied by int_multiple
*/
-TempBuf *
+GimpTempBuf *
gimp_brush_real_transform_pixmap (GimpBrush *brush,
gdouble scale,
gdouble aspect_ratio,
gdouble angle,
gdouble hardness)
{
- TempBuf *result;
- TempBuf *source;
+ GimpTempBuf *result;
+ GimpTempBuf *source;
guchar *dest;
const guchar *src;
GimpMatrix3 matrix;
@@ -628,7 +628,7 @@ gimp_brush_real_transform_pixmap (GimpBrush *brush,
if (hardness < 1.0)
{
- TempBuf *blur_src;
+ GimpTempBuf *blur_src;
GeglBuffer *src_buffer;
GeglBuffer *dest_buffer;
gint kernel_size =
@@ -700,7 +700,7 @@ gimp_brush_transform_matrix (gdouble width,
/* private functions */
static void
-gimp_brush_transform_bounding_box (TempBuf *brush,
+gimp_brush_transform_bounding_box (GimpTempBuf *brush,
const GimpMatrix3 *matrix,
gint *x,
gint *y,
diff --git a/app/core/gimpbrush-transform.h b/app/core/gimpbrush-transform.h
index 6220b06..4f4ac62 100644
--- a/app/core/gimpbrush-transform.h
+++ b/app/core/gimpbrush-transform.h
@@ -23,29 +23,29 @@
/* virtual functions of GimpBrush, don't call directly */
-void gimp_brush_real_transform_size (GimpBrush *brush,
- gdouble scale,
- gdouble aspect_ratio,
- gdouble angle,
- gint *scaled_width,
- gint *scaled_height);
-TempBuf * gimp_brush_real_transform_mask (GimpBrush *brush,
- gdouble scale,
- gdouble aspect_ratio,
- gdouble angle,
- gdouble hardness);
-TempBuf * gimp_brush_real_transform_pixmap (GimpBrush *brush,
- gdouble scale,
- gdouble aspect_ratio,
- gdouble angle,
- gdouble hardness);
+void gimp_brush_real_transform_size (GimpBrush *brush,
+ gdouble scale,
+ gdouble aspect_ratio,
+ gdouble angle,
+ gint *scaled_width,
+ gint *scaled_height);
+GimpTempBuf * gimp_brush_real_transform_mask (GimpBrush *brush,
+ gdouble scale,
+ gdouble aspect_ratio,
+ gdouble angle,
+ gdouble hardness);
+GimpTempBuf * gimp_brush_real_transform_pixmap (GimpBrush *brush,
+ gdouble scale,
+ gdouble aspect_ratio,
+ gdouble angle,
+ gdouble hardness);
-void gimp_brush_transform_matrix (gdouble width,
- gdouble height,
- gdouble scale,
- gdouble aspect_ratio,
- gdouble angle,
- GimpMatrix3 *matrix);
+void gimp_brush_transform_matrix (gdouble width,
+ gdouble height,
+ gdouble scale,
+ gdouble aspect_ratio,
+ gdouble angle,
+ GimpMatrix3 *matrix);
#endif /* __GIMP_BRUSH_TRANSFORM_H__ */
diff --git a/app/core/gimpbrush.c b/app/core/gimpbrush.c
index 3f1c992..109c952 100644
--- a/app/core/gimpbrush.c
+++ b/app/core/gimpbrush.c
@@ -71,7 +71,7 @@ static gint64 gimp_brush_get_memsize (GimpObject *obj
static gboolean gimp_brush_get_size (GimpViewable *viewable,
gint *width,
gint *height);
-static TempBuf * gimp_brush_get_new_preview (GimpViewable *viewable,
+static GimpTempBuf * gimp_brush_get_new_preview (GimpViewable *viewable,
GimpContext *context,
gint width,
gint height);
@@ -275,23 +275,23 @@ gimp_brush_get_size (GimpViewable *viewable,
return TRUE;
}
-static TempBuf *
+static GimpTempBuf *
gimp_brush_get_new_preview (GimpViewable *viewable,
GimpContext *context,
gint width,
gint height)
{
- GimpBrush *brush = GIMP_BRUSH (viewable);
- const TempBuf *mask_buf = NULL;
- gboolean free_mask = FALSE;
- const TempBuf *pixmap_buf = NULL;
- TempBuf *return_buf = NULL;
- gint mask_width;
- gint mask_height;
- guchar *mask;
- guchar *buf;
- gint x, y;
- gboolean scaled = FALSE;
+ GimpBrush *brush = GIMP_BRUSH (viewable);
+ const GimpTempBuf *mask_buf = NULL;
+ gboolean free_mask = FALSE;
+ const GimpTempBuf *pixmap_buf = NULL;
+ GimpTempBuf *return_buf = NULL;
+ gint mask_width;
+ gint mask_height;
+ guchar *mask;
+ guchar *buf;
+ gint x, y;
+ gboolean scaled = FALSE;
mask_buf = brush->mask;
pixmap_buf = brush->pixmap;
@@ -315,7 +315,7 @@ gimp_brush_get_new_preview (GimpViewable *viewable,
if (! mask_buf)
{
mask_buf = temp_buf_new (1, 1, babl_format ("Y u8"));
- temp_buf_data_clear ((TempBuf *) mask_buf);
+ temp_buf_data_clear ((GimpTempBuf *) mask_buf);
free_mask = TRUE;
}
@@ -369,7 +369,7 @@ gimp_brush_get_new_preview (GimpViewable *viewable,
if (scaled)
{
if (free_mask)
- temp_buf_free ((TempBuf *) mask_buf);
+ temp_buf_free ((GimpTempBuf *) mask_buf);
gimp_brush_end_use (brush);
}
@@ -590,16 +590,16 @@ gimp_brush_transform_size (GimpBrush *brush,
width, height);
}
-const TempBuf *
+const GimpTempBuf *
gimp_brush_transform_mask (GimpBrush *brush,
gdouble scale,
gdouble aspect_ratio,
gdouble angle,
gdouble hardness)
{
- const TempBuf *mask;
- gint width;
- gint height;
+ const GimpTempBuf *mask;
+ gint width;
+ gint height;
g_return_val_if_fail (GIMP_IS_BRUSH (brush), NULL);
g_return_val_if_fail (scale > 0.0, NULL);
@@ -639,16 +639,16 @@ gimp_brush_transform_mask (GimpBrush *brush,
return mask;
}
-const TempBuf *
+const GimpTempBuf *
gimp_brush_transform_pixmap (GimpBrush *brush,
gdouble scale,
gdouble aspect_ratio,
gdouble angle,
gdouble hardness)
{
- const TempBuf *pixmap;
- gint width;
- gint height;
+ const GimpTempBuf *pixmap;
+ gint width;
+ gint height;
g_return_val_if_fail (GIMP_IS_BRUSH (brush), NULL);
g_return_val_if_fail (brush->pixmap != NULL, NULL);
@@ -739,7 +739,7 @@ gimp_brush_transform_boundary (GimpBrush *brush,
return boundary;
}
-TempBuf *
+GimpTempBuf *
gimp_brush_get_mask (const GimpBrush *brush)
{
g_return_val_if_fail (brush != NULL, NULL);
@@ -748,7 +748,7 @@ gimp_brush_get_mask (const GimpBrush *brush)
return brush->mask;
}
-TempBuf *
+GimpTempBuf *
gimp_brush_get_pixmap (const GimpBrush *brush)
{
g_return_val_if_fail (brush != NULL, NULL);
diff --git a/app/core/gimpbrush.h b/app/core/gimpbrush.h
index ef518a6..67af0c6 100644
--- a/app/core/gimpbrush.h
+++ b/app/core/gimpbrush.h
@@ -36,8 +36,8 @@ struct _GimpBrush
{
GimpData parent_instance;
- TempBuf *mask; /* the actual mask */
- TempBuf *pixmap; /* optional pixmap data */
+ GimpTempBuf *mask; /* the actual mask */
+ GimpTempBuf *pixmap; /* optional pixmap data */
gint spacing; /* brush's spacing */
GimpVector2 x_axis; /* for calculating brush spacing */
@@ -68,12 +68,12 @@ struct _GimpBrushClass
gdouble angle,
gint *width,
gint *height);
- TempBuf * (* transform_mask) (GimpBrush *brush,
+ GimpTempBuf * (* transform_mask) (GimpBrush *brush,
gdouble scale,
gdouble aspect_ratio,
gdouble angle,
gdouble hardness);
- TempBuf * (* transform_pixmap) (GimpBrush *brush,
+ GimpTempBuf * (* transform_pixmap) (GimpBrush *brush,
gdouble scale,
gdouble aspect_ratio,
gdouble angle,
@@ -116,12 +116,12 @@ void gimp_brush_transform_size (GimpBrush *brush,
gdouble angle,
gint *width,
gint *height);
-const TempBuf * gimp_brush_transform_mask (GimpBrush *brush,
+const GimpTempBuf * gimp_brush_transform_mask (GimpBrush *brush,
gdouble scale,
gdouble aspect_ratio,
gdouble angle,
gdouble hardness);
-const TempBuf * gimp_brush_transform_pixmap (GimpBrush *brush,
+const GimpTempBuf * gimp_brush_transform_pixmap (GimpBrush *brush,
gdouble scale,
gdouble aspect_ratio,
gdouble angle,
@@ -134,8 +134,8 @@ const GimpBezierDesc * gimp_brush_transform_boundary (GimpBrush *brush,
gint *width,
gint *height);
-TempBuf * gimp_brush_get_mask (const GimpBrush *brush);
-TempBuf * gimp_brush_get_pixmap (const GimpBrush *brush);
+GimpTempBuf * gimp_brush_get_mask (const GimpBrush *brush);
+GimpTempBuf * gimp_brush_get_pixmap (const GimpBrush *brush);
gint gimp_brush_get_spacing (const GimpBrush *brush);
void gimp_brush_set_spacing (GimpBrush *brush,
diff --git a/app/core/gimpbrushgenerated.c b/app/core/gimpbrushgenerated.c
index 2dd3774..7d4fd29 100644
--- a/app/core/gimpbrushgenerated.c
+++ b/app/core/gimpbrushgenerated.c
@@ -71,13 +71,13 @@ static void gimp_brush_generated_transform_size(GimpBrush *gbrush,
gdouble angle,
gint *width,
gint *height);
-static TempBuf * gimp_brush_generated_transform_mask(GimpBrush *gbrush,
+static GimpTempBuf * gimp_brush_generated_transform_mask(GimpBrush *gbrush,
gdouble scale,
gdouble aspect_ratio,
gdouble angle,
gdouble hardness);
-static TempBuf * gimp_brush_generated_calc (GimpBrushGenerated *brush,
+static GimpTempBuf * gimp_brush_generated_calc (GimpBrushGenerated *brush,
GimpBrushGeneratedShape shape,
gfloat radius,
gint spikes,
@@ -336,7 +336,7 @@ gimp_brush_generated_transform_size (GimpBrush *gbrush,
*height = half_height * 2 + 1;
}
-static TempBuf *
+static GimpTempBuf *
gimp_brush_generated_transform_mask (GimpBrush *gbrush,
gdouble scale,
gdouble aspect_ratio,
@@ -450,7 +450,7 @@ gimp_brush_generated_calc_lut (gdouble radius,
return lookup;
}
-static TempBuf *
+static GimpTempBuf *
gimp_brush_generated_calc (GimpBrushGenerated *brush,
GimpBrushGeneratedShape shape,
gfloat radius,
@@ -470,7 +470,7 @@ gimp_brush_generated_calc (GimpBrushGenerated *brush,
gdouble c, s, cs, ss;
GimpVector2 x_axis;
GimpVector2 y_axis;
- TempBuf *mask;
+ GimpTempBuf *mask;
gimp_brush_generated_get_half_size (brush,
shape,
diff --git a/app/core/gimpbuffer.c b/app/core/gimpbuffer.c
index 139476a..2120183 100644
--- a/app/core/gimpbuffer.c
+++ b/app/core/gimpbuffer.c
@@ -31,32 +31,32 @@
#include "gimpimage.h"
-static void gimp_buffer_finalize (GObject *object);
-
-static gint64 gimp_buffer_get_memsize (GimpObject *object,
- gint64 *gui_size);
-
-static gboolean gimp_buffer_get_size (GimpViewable *viewable,
- gint *width,
- gint *height);
-static void gimp_buffer_get_preview_size (GimpViewable *viewable,
- gint size,
- gboolean is_popup,
- gboolean dot_for_dot,
- gint *popup_width,
- gint *popup_height);
-static gboolean gimp_buffer_get_popup_size (GimpViewable *viewable,
- gint width,
- gint height,
- gboolean dot_for_dot,
- gint *popup_width,
- gint *popup_height);
-static TempBuf * gimp_buffer_get_new_preview (GimpViewable *viewable,
- GimpContext *context,
- gint width,
- gint height);
-static gchar * gimp_buffer_get_description (GimpViewable *viewable,
- gchar **tooltip);
+static void gimp_buffer_finalize (GObject *object);
+
+static gint64 gimp_buffer_get_memsize (GimpObject *object,
+ gint64 *gui_size);
+
+static gboolean gimp_buffer_get_size (GimpViewable *viewable,
+ gint *width,
+ gint *height);
+static void gimp_buffer_get_preview_size (GimpViewable *viewable,
+ gint size,
+ gboolean is_popup,
+ gboolean dot_for_dot,
+ gint *popup_width,
+ gint *popup_height);
+static gboolean gimp_buffer_get_popup_size (GimpViewable *viewable,
+ gint width,
+ gint height,
+ gboolean dot_for_dot,
+ gint *popup_width,
+ gint *popup_height);
+static GimpTempBuf * gimp_buffer_get_new_preview (GimpViewable *viewable,
+ GimpContext *context,
+ gint width,
+ gint height);
+static gchar * gimp_buffer_get_description (GimpViewable *viewable,
+ gchar **tooltip);
G_DEFINE_TYPE (GimpBuffer, gimp_buffer, GIMP_TYPE_VIEWABLE)
@@ -189,14 +189,14 @@ gimp_buffer_get_popup_size (GimpViewable *viewable,
return FALSE;
}
-static TempBuf *
+static GimpTempBuf *
gimp_buffer_get_new_preview (GimpViewable *viewable,
GimpContext *context,
gint width,
gint height)
{
- GimpBuffer *buffer = GIMP_BUFFER (viewable);
- TempBuf *preview;
+ GimpBuffer *buffer = GIMP_BUFFER (viewable);
+ GimpTempBuf *preview;
preview = temp_buf_new (width, height, gimp_buffer_get_format (buffer));
diff --git a/app/core/gimpcurve.c b/app/core/gimpcurve.c
index 8c031f8..667c702 100644
--- a/app/core/gimpcurve.c
+++ b/app/core/gimpcurve.c
@@ -74,7 +74,7 @@ static gboolean gimp_curve_get_popup_size (GimpViewable *viewable,
gboolean dot_for_dot,
gint *popup_width,
gint *popup_height);
-static TempBuf * gimp_curve_get_new_preview (GimpViewable *viewable,
+static GimpTempBuf * gimp_curve_get_new_preview (GimpViewable *viewable,
GimpContext *context,
gint width,
gint height);
@@ -395,7 +395,7 @@ gimp_curve_get_popup_size (GimpViewable *viewable,
return TRUE;
}
-static TempBuf *
+static GimpTempBuf *
gimp_curve_get_new_preview (GimpViewable *viewable,
GimpContext *context,
gint width,
diff --git a/app/core/gimpdrawable-combine.c b/app/core/gimpdrawable-combine.c
index 19e8ee7..d04e0b1 100644
--- a/app/core/gimpdrawable-combine.c
+++ b/app/core/gimpdrawable-combine.c
@@ -258,7 +258,7 @@ gimp_drawable_real_replace_buffer (GimpDrawable *drawable,
GimpItem *item = GIMP_ITEM (drawable);
GimpImage *image = gimp_item_get_image (item);
GimpChannel *mask = gimp_image_get_mask (image);
- TempBuf *temp_buf;
+ GimpTempBuf *temp_buf;
PixelRegion src2PR;
gint x, y, width, height;
gint offset_x, offset_y;
diff --git a/app/core/gimpdrawable-preview.c b/app/core/gimpdrawable-preview.c
index b921874..76b898b 100644
--- a/app/core/gimpdrawable-preview.c
+++ b/app/core/gimpdrawable-preview.c
@@ -46,22 +46,22 @@
/* local function prototypes */
-static TempBuf * gimp_drawable_preview_private (GimpDrawable *drawable,
- gint width,
- gint height);
-static TempBuf * gimp_drawable_indexed_preview (GimpDrawable *drawable,
- const guchar *cmap,
- gint src_x,
- gint src_y,
- gint src_width,
- gint src_height,
- gint dest_width,
- gint dest_height);
+static GimpTempBuf * gimp_drawable_preview_private (GimpDrawable *drawable,
+ gint width,
+ gint height);
+static GimpTempBuf * gimp_drawable_indexed_preview (GimpDrawable *drawable,
+ const guchar *cmap,
+ gint src_x,
+ gint src_y,
+ gint src_width,
+ gint src_height,
+ gint dest_width,
+ gint dest_height);
/* public functions */
-TempBuf *
+GimpTempBuf *
gimp_drawable_get_preview (GimpViewable *viewable,
GimpContext *context,
gint width,
@@ -84,9 +84,9 @@ gimp_drawable_get_preview (GimpViewable *viewable,
gimp_image_get_width (image) > PREVIEW_CACHE_PRIME_WIDTH &&
gimp_image_get_height (image) > PREVIEW_CACHE_PRIME_HEIGHT)
{
- TempBuf *tb = gimp_drawable_preview_private (drawable,
- PREVIEW_CACHE_PRIME_WIDTH,
- PREVIEW_CACHE_PRIME_HEIGHT);
+ GimpTempBuf *tb = gimp_drawable_preview_private (drawable,
+ PREVIEW_CACHE_PRIME_WIDTH,
+ PREVIEW_CACHE_PRIME_HEIGHT);
/* Save the 2nd call */
if (width == PREVIEW_CACHE_PRIME_WIDTH &&
@@ -120,7 +120,7 @@ gimp_drawable_preview_bytes (GimpDrawable *drawable)
return bytes;
}
-TempBuf *
+GimpTempBuf *
gimp_drawable_get_sub_preview (GimpDrawable *drawable,
gint src_x,
gint src_y,
@@ -164,12 +164,12 @@ gimp_drawable_get_sub_preview (GimpDrawable *drawable,
/* private functions */
-static TempBuf *
+static GimpTempBuf *
gimp_drawable_preview_private (GimpDrawable *drawable,
gint width,
gint height)
{
- TempBuf *ret_buf;
+ GimpTempBuf *ret_buf;
if (! drawable->private->preview_valid ||
! (ret_buf = gimp_preview_cache_get (&drawable->private->preview_cache,
@@ -195,7 +195,7 @@ gimp_drawable_preview_private (GimpDrawable *drawable,
return ret_buf;
}
-static TempBuf *
+static GimpTempBuf *
gimp_drawable_indexed_preview (GimpDrawable *drawable,
const guchar *cmap,
gint src_x,
@@ -205,7 +205,7 @@ gimp_drawable_indexed_preview (GimpDrawable *drawable,
gint dest_width,
gint dest_height)
{
- TempBuf *preview_buf;
+ GimpTempBuf *preview_buf;
PixelRegion srcPR;
PixelRegion destPR;
gint bytes = gimp_drawable_preview_bytes (drawable);
diff --git a/app/core/gimpdrawable-preview.h b/app/core/gimpdrawable-preview.h
index 1435810..4993774 100644
--- a/app/core/gimpdrawable-preview.h
+++ b/app/core/gimpdrawable-preview.h
@@ -22,22 +22,22 @@
/*
* virtual function of GimpDrawable -- dont't call directly
*/
-TempBuf * gimp_drawable_get_preview (GimpViewable *viewable,
- GimpContext *context,
- gint width,
- gint height);
+GimpTempBuf * gimp_drawable_get_preview (GimpViewable *viewable,
+ GimpContext *context,
+ gint width,
+ gint height);
/*
* normal functions (no virtuals)
*/
-gint gimp_drawable_preview_bytes (GimpDrawable *drawable);
-TempBuf * gimp_drawable_get_sub_preview (GimpDrawable *drawable,
- gint src_x,
- gint src_y,
- gint src_width,
- gint src_height,
- gint dest_width,
- gint dest_height);
+gint gimp_drawable_preview_bytes (GimpDrawable *drawable);
+GimpTempBuf * gimp_drawable_get_sub_preview (GimpDrawable *drawable,
+ gint src_x,
+ gint src_y,
+ gint src_width,
+ gint src_height,
+ gint dest_width,
+ gint dest_height);
#endif /* __GIMP_DRAWABLE__PREVIEW_H__ */
diff --git a/app/core/gimpgradient.c b/app/core/gimpgradient.c
index aabf95b..247cfc4 100644
--- a/app/core/gimpgradient.c
+++ b/app/core/gimpgradient.c
@@ -57,7 +57,7 @@ static gboolean gimp_gradient_get_popup_size (GimpViewable *viewa
gboolean dot_for_dot,
gint *popup_width,
gint *popup_height);
-static TempBuf * gimp_gradient_get_new_preview (GimpViewable *viewable,
+static GimpTempBuf * gimp_gradient_get_new_preview (GimpViewable *viewable,
GimpContext *context,
gint width,
gint height);
@@ -185,7 +185,7 @@ gimp_gradient_get_popup_size (GimpViewable *viewable,
return FALSE;
}
-static TempBuf *
+static GimpTempBuf *
gimp_gradient_get_new_preview (GimpViewable *viewable,
GimpContext *context,
gint width,
@@ -193,7 +193,7 @@ gimp_gradient_get_new_preview (GimpViewable *viewable,
{
GimpGradient *gradient = GIMP_GRADIENT (viewable);
GimpGradientSegment *seg = NULL;
- TempBuf *temp_buf;
+ GimpTempBuf *temp_buf;
guchar *buf;
guchar *p;
guchar *row;
diff --git a/app/core/gimpimage-preview.c b/app/core/gimpimage-preview.c
index 8e77c0e..38a1e6f 100644
--- a/app/core/gimpimage-preview.c
+++ b/app/core/gimpimage-preview.c
@@ -92,7 +92,7 @@ gimp_image_get_popup_size (GimpViewable *viewable,
return FALSE;
}
-TempBuf *
+GimpTempBuf *
gimp_image_get_preview (GimpViewable *viewable,
GimpContext *context,
gint width,
@@ -120,7 +120,7 @@ gimp_image_get_preview (GimpViewable *viewable,
}
}
-TempBuf *
+GimpTempBuf *
gimp_image_get_new_preview (GimpViewable *viewable,
GimpContext *context,
gint width,
@@ -128,7 +128,7 @@ gimp_image_get_new_preview (GimpViewable *viewable,
{
GimpImage *image = GIMP_IMAGE (viewable);
GimpProjection *projection = gimp_image_get_projection (image);
- TempBuf *buf;
+ GimpTempBuf *buf;
TileManager *tiles;
gdouble scale_x;
gdouble scale_y;
diff --git a/app/core/gimpimage-preview.h b/app/core/gimpimage-preview.h
index 04fed0b..e4252ea 100644
--- a/app/core/gimpimage-preview.h
+++ b/app/core/gimpimage-preview.h
@@ -23,26 +23,26 @@
* virtual functions of GimpImage -- dont't call directly
*/
-void gimp_image_get_preview_size (GimpViewable *viewable,
- gint size,
- gboolean is_popup,
- gboolean dot_for_dot,
- gint *width,
- gint *height);
-gboolean gimp_image_get_popup_size (GimpViewable *viewable,
- gint width,
- gint height,
- gboolean dot_for_dot,
- gint *popup_width,
- gint *popup_height);
-TempBuf * gimp_image_get_preview (GimpViewable *viewable,
- GimpContext *context,
- gint width,
- gint height);
-TempBuf * gimp_image_get_new_preview (GimpViewable *viewable,
- GimpContext *context,
- gint width,
- gint height);
+void gimp_image_get_preview_size (GimpViewable *viewable,
+ gint size,
+ gboolean is_popup,
+ gboolean dot_for_dot,
+ gint *width,
+ gint *height);
+gboolean gimp_image_get_popup_size (GimpViewable *viewable,
+ gint width,
+ gint height,
+ gboolean dot_for_dot,
+ gint *popup_width,
+ gint *popup_height);
+GimpTempBuf * gimp_image_get_preview (GimpViewable *viewable,
+ GimpContext *context,
+ gint width,
+ gint height);
+GimpTempBuf * gimp_image_get_new_preview (GimpViewable *viewable,
+ GimpContext *context,
+ gint width,
+ gint height);
#endif /* __GIMP_IMAGE_PREVIEW_H__ */
diff --git a/app/core/gimpimage-private.h b/app/core/gimpimage-private.h
index 97dcc46..2146f8b 100644
--- a/app/core/gimpimage-private.h
+++ b/app/core/gimpimage-private.h
@@ -100,7 +100,7 @@ struct _GimpImagePrivate
GimpUndoType pushing_undo_group; /* undo group status flag */
/* Preview */
- TempBuf *preview; /* the projection preview */
+ GimpTempBuf *preview; /* the projection preview */
/* Signal emmision accumulator */
GimpImageFlushAccumulator flush_accum;
diff --git a/app/core/gimppalette.c b/app/core/gimppalette.c
index e4901d9..2cf9904 100644
--- a/app/core/gimppalette.c
+++ b/app/core/gimppalette.c
@@ -60,7 +60,7 @@ static gboolean gimp_palette_get_popup_size (GimpViewable *viewa
gboolean dot_for_dot,
gint *popup_width,
gint *popup_height);
-static TempBuf * gimp_palette_get_new_preview (GimpViewable *viewable,
+static GimpTempBuf * gimp_palette_get_new_preview (GimpViewable *viewable,
GimpContext *context,
gint width,
gint height);
@@ -195,14 +195,14 @@ gimp_palette_get_popup_size (GimpViewable *viewable,
return FALSE;
}
-static TempBuf *
+static GimpTempBuf *
gimp_palette_get_new_preview (GimpViewable *viewable,
GimpContext *context,
gint width,
gint height)
{
GimpPalette *palette = GIMP_PALETTE (viewable);
- TempBuf *temp_buf;
+ GimpTempBuf *temp_buf;
guchar *buf;
guchar *b;
GList *list;
diff --git a/app/core/gimppattern.c b/app/core/gimppattern.c
index d695951..5e8efcf 100644
--- a/app/core/gimppattern.c
+++ b/app/core/gimppattern.c
@@ -45,7 +45,7 @@ static gint64 gimp_pattern_get_memsize (GimpObject *objec
static gboolean gimp_pattern_get_size (GimpViewable *viewable,
gint *width,
gint *height);
-static TempBuf * gimp_pattern_get_new_preview (GimpViewable *viewable,
+static GimpTempBuf * gimp_pattern_get_new_preview (GimpViewable *viewable,
GimpContext *context,
gint width,
gint height);
@@ -138,14 +138,14 @@ gimp_pattern_get_size (GimpViewable *viewable,
return TRUE;
}
-static TempBuf *
+static GimpTempBuf *
gimp_pattern_get_new_preview (GimpViewable *viewable,
GimpContext *context,
gint width,
gint height)
{
GimpPattern *pattern = GIMP_PATTERN (viewable);
- TempBuf *temp_buf;
+ GimpTempBuf *temp_buf;
GeglBuffer *src_buffer;
GeglBuffer *dest_buffer;
gint copy_width;
@@ -265,7 +265,7 @@ gimp_pattern_get_standard (GimpContext *context)
return standard_pattern;
}
-TempBuf *
+GimpTempBuf *
gimp_pattern_get_mask (const GimpPattern *pattern)
{
g_return_val_if_fail (GIMP_IS_PATTERN (pattern), NULL);
diff --git a/app/core/gimppattern.h b/app/core/gimppattern.h
index 31a03e0..9e6350c 100644
--- a/app/core/gimppattern.h
+++ b/app/core/gimppattern.h
@@ -34,9 +34,9 @@ typedef struct _GimpPatternClass GimpPatternClass;
struct _GimpPattern
{
- GimpData parent_instance;
+ GimpData parent_instance;
- TempBuf *mask;
+ GimpTempBuf *mask;
};
struct _GimpPatternClass
@@ -45,14 +45,14 @@ struct _GimpPatternClass
};
-GType gimp_pattern_get_type (void) G_GNUC_CONST;
+GType gimp_pattern_get_type (void) G_GNUC_CONST;
-GimpData * gimp_pattern_new (GimpContext *context,
- const gchar *name);
-GimpData * gimp_pattern_get_standard (GimpContext *context);
+GimpData * gimp_pattern_new (GimpContext *context,
+ const gchar *name);
+GimpData * gimp_pattern_get_standard (GimpContext *context);
-TempBuf * gimp_pattern_get_mask (const GimpPattern *pattern);
-GeglBuffer * gimp_pattern_create_buffer (const GimpPattern *pattern);
+GimpTempBuf * gimp_pattern_get_mask (const GimpPattern *pattern);
+GeglBuffer * gimp_pattern_create_buffer (const GimpPattern *pattern);
#endif /* __GIMP_PATTERN_H__ */
diff --git a/app/core/gimppreviewcache.c b/app/core/gimppreviewcache.c
index b493c74..e7c0094 100644
--- a/app/core/gimppreviewcache.c
+++ b/app/core/gimppreviewcache.c
@@ -31,9 +31,9 @@
typedef struct
{
- TempBuf *buf;
- gint width;
- gint height;
+ GimpTempBuf *buf;
+ gint width;
+ gint height;
} PreviewNearest;
@@ -41,8 +41,8 @@ static gint
preview_cache_compare (gconstpointer a,
gconstpointer b)
{
- const TempBuf *buf1 = a;
- const TempBuf *buf2 = b;
+ const GimpTempBuf *buf1 = a;
+ const GimpTempBuf *buf2 = b;
if (buf1->width > buf2->width && buf1->height > buf2->height)
return -1;
@@ -54,7 +54,7 @@ static void
preview_cache_find_exact (gpointer data,
gpointer udata)
{
- TempBuf *buf = data;
+ GimpTempBuf *buf = data;
PreviewNearest *nearest = udata;
if (nearest->buf)
@@ -71,7 +71,7 @@ static void
preview_cache_find_biggest (gpointer data,
gpointer udata)
{
- TempBuf *buf = data;
+ GimpTempBuf *buf = data;
PreviewNearest *nearest = udata;
if (buf->width >= nearest->width && buf->height >= nearest->height)
@@ -93,8 +93,8 @@ preview_cache_find_biggest (gpointer data,
static void
preview_cache_remove_smallest (GSList **plist)
{
- GSList *list;
- TempBuf *smallest = NULL;
+ GSList *list;
+ GimpTempBuf *smallest = NULL;
#ifdef PREVIEW_CACHE_DEBUG
g_print ("preview_cache_remove_smallest\n");
@@ -108,7 +108,7 @@ preview_cache_remove_smallest (GSList **plist)
}
else
{
- TempBuf *this = list->data;
+ GimpTempBuf *this = list->data;
if (smallest->height * smallest->width > this->height * this->width)
{
@@ -140,7 +140,7 @@ preview_cache_print (GSList *plist)
for (list = plist; list; list = list->next)
{
- TempBuf *buf = (TempBuf *) list->data;
+ GimpTempBuf *buf = list->data;
g_print ("\tvalue w,h [%d,%d]\n", buf->width, buf->height);
}
@@ -160,8 +160,8 @@ gimp_preview_cache_invalidate (GSList **plist)
}
void
-gimp_preview_cache_add (GSList **plist,
- TempBuf *buf)
+gimp_preview_cache_add (GSList **plist,
+ GimpTempBuf *buf)
{
#ifdef PREVIEW_CACHE_DEBUG
g_print ("gimp_preview_cache_add: %d x %d\n", buf->width, buf->height);
@@ -176,7 +176,7 @@ gimp_preview_cache_add (GSList **plist,
*plist = g_slist_insert_sorted (*plist, buf, preview_cache_compare);
}
-TempBuf *
+GimpTempBuf *
gimp_preview_cache_get (GSList **plist,
gint width,
gint height)
@@ -208,16 +208,16 @@ gimp_preview_cache_get (GSList **plist,
if (pn.buf)
{
- TempBuf *preview;
- gint pwidth;
- gint pheight;
- gdouble x_ratio;
- gdouble y_ratio;
- guchar *src_data;
- guchar *dest_data;
- gint bytes;
- gint loop1;
- gint loop2;
+ GimpTempBuf *preview;
+ gint pwidth;
+ gint pheight;
+ gdouble x_ratio;
+ gdouble y_ratio;
+ guchar *src_data;
+ guchar *dest_data;
+ gint bytes;
+ gint loop1;
+ gint loop2;
#ifdef PREVIEW_CACHE_DEBUG
g_print ("gimp_preview_cache_get: nearest value: %d x %d\n",
@@ -287,7 +287,7 @@ gimp_preview_cache_get_memsize (GSList *cache)
return 0;
for (list = cache; list; list = list->next)
- memsize += sizeof (GSList) + temp_buf_get_memsize ((TempBuf *) list->data);
+ memsize += sizeof (GSList) + temp_buf_get_memsize (list->data);
return memsize;
}
diff --git a/app/core/gimppreviewcache.h b/app/core/gimppreviewcache.h
index 6ec9649..bf216eb 100644
--- a/app/core/gimppreviewcache.h
+++ b/app/core/gimppreviewcache.h
@@ -23,14 +23,14 @@
#define PREVIEW_CACHE_PRIME_HEIGHT 112
-TempBuf * gimp_preview_cache_get (GSList **plist,
- gint width,
- gint height);
-void gimp_preview_cache_add (GSList **plist,
- TempBuf *buf);
-void gimp_preview_cache_invalidate (GSList **plist);
-
-gsize gimp_preview_cache_get_memsize (GSList *cache);
+GimpTempBuf * gimp_preview_cache_get (GSList **plist,
+ gint width,
+ gint height);
+void gimp_preview_cache_add (GSList **plist,
+ GimpTempBuf *buf);
+void gimp_preview_cache_invalidate (GSList **plist);
+
+gsize gimp_preview_cache_get_memsize (GSList *cache);
#endif /* __GIMP_PREVIEW_CACHE_H__ */
diff --git a/app/core/gimpundo.c b/app/core/gimpundo.c
index 908b250..922968b 100644
--- a/app/core/gimpundo.c
+++ b/app/core/gimpundo.c
@@ -57,40 +57,40 @@ enum
};
-static void gimp_undo_constructed (GObject *object);
-static void gimp_undo_finalize (GObject *object);
-static void gimp_undo_set_property (GObject *object,
- guint property_id,
- const GValue *value,
- GParamSpec *pspec);
-static void gimp_undo_get_property (GObject *object,
- guint property_id,
- GValue *value,
- GParamSpec *pspec);
-
-static gint64 gimp_undo_get_memsize (GimpObject *object,
- gint64 *gui_size);
-
-static gboolean gimp_undo_get_popup_size (GimpViewable *viewable,
- gint width,
- gint height,
- gboolean dot_for_dot,
- gint *popup_width,
- gint *popup_height);
-static TempBuf * gimp_undo_get_new_preview (GimpViewable *viewable,
- GimpContext *context,
- gint width,
- gint height);
-
-static void gimp_undo_real_pop (GimpUndo *undo,
- GimpUndoMode undo_mode,
- GimpUndoAccumulator *accum);
-static void gimp_undo_real_free (GimpUndo *undo,
- GimpUndoMode undo_mode);
-
-static gboolean gimp_undo_create_preview_idle (gpointer data);
-static void gimp_undo_create_preview_private (GimpUndo *undo,
- GimpContext *context);
+static void gimp_undo_constructed (GObject *object);
+static void gimp_undo_finalize (GObject *object);
+static void gimp_undo_set_property (GObject *object,
+ guint property_id,
+ const GValue *value,
+ GParamSpec *pspec);
+static void gimp_undo_get_property (GObject *object,
+ guint property_id,
+ GValue *value,
+ GParamSpec *pspec);
+
+static gint64 gimp_undo_get_memsize (GimpObject *object,
+ gint64 *gui_size);
+
+static gboolean gimp_undo_get_popup_size (GimpViewable *viewable,
+ gint width,
+ gint height,
+ gboolean dot_for_dot,
+ gint *popup_width,
+ gint *popup_height);
+static GimpTempBuf * gimp_undo_get_new_preview (GimpViewable *viewable,
+ GimpContext *context,
+ gint width,
+ gint height);
+
+static void gimp_undo_real_pop (GimpUndo *undo,
+ GimpUndoMode undo_mode,
+ GimpUndoAccumulator *accum);
+static void gimp_undo_real_free (GimpUndo *undo,
+ GimpUndoMode undo_mode);
+
+static gboolean gimp_undo_create_preview_idle (gpointer data);
+static void gimp_undo_create_preview_private (GimpUndo *undo,
+ GimpContext *context);
G_DEFINE_TYPE (GimpUndo, gimp_undo, GIMP_TYPE_VIEWABLE)
@@ -300,7 +300,7 @@ gimp_undo_get_popup_size (GimpViewable *viewable,
return FALSE;
}
-static TempBuf *
+static GimpTempBuf *
gimp_undo_get_new_preview (GimpViewable *viewable,
GimpContext *context,
gint width,
diff --git a/app/core/gimpundo.h b/app/core/gimpundo.h
index b5dec67..d3d1584 100644
--- a/app/core/gimpundo.h
+++ b/app/core/gimpundo.h
@@ -58,7 +58,7 @@ struct _GimpUndo
GimpUndoType undo_type; /* undo type */
GimpDirtyMask dirty_mask; /* affected parts of the image */
- TempBuf *preview;
+ GimpTempBuf *preview;
guint preview_idle_id;
};
diff --git a/app/core/gimpviewable.h b/app/core/gimpviewable.h
index 9b32a48..9af188f 100644
--- a/app/core/gimpviewable.h
+++ b/app/core/gimpviewable.h
@@ -77,11 +77,11 @@ struct _GimpViewableClass
gboolean dot_for_dot,
gint *popup_width,
gint *popup_height);
- TempBuf * (* get_preview) (GimpViewable *viewable,
+ GimpTempBuf * (* get_preview) (GimpViewable *viewable,
GimpContext *context,
gint width,
gint height);
- TempBuf * (* get_new_preview) (GimpViewable *viewable,
+ GimpTempBuf * (* get_new_preview) (GimpViewable *viewable,
GimpContext *context,
gint width,
gint height);
@@ -136,16 +136,16 @@ gboolean gimp_viewable_get_popup_size (GimpViewable *viewable,
gint *popup_width,
gint *popup_height);
-TempBuf * gimp_viewable_get_preview (GimpViewable *viewable,
+GimpTempBuf * gimp_viewable_get_preview (GimpViewable *viewable,
GimpContext *context,
gint width,
gint height);
-TempBuf * gimp_viewable_get_new_preview (GimpViewable *viewable,
+GimpTempBuf * gimp_viewable_get_new_preview (GimpViewable *viewable,
GimpContext *context,
gint width,
gint height);
-TempBuf * gimp_viewable_get_dummy_preview (GimpViewable *viewable,
+GimpTempBuf * gimp_viewable_get_dummy_preview (GimpViewable *viewable,
gint width,
gint height,
gint bpp);
diff --git a/app/gegl/gimp-gegl-utils.c b/app/gegl/gimp-gegl-utils.c
index 763ea36..58599c2 100644
--- a/app/gegl/gimp-gegl-utils.c
+++ b/app/gegl/gimp-gegl-utils.c
@@ -244,7 +244,7 @@ gimp_gegl_buffer_get_tiles (GeglBuffer *buffer)
return gimp_tile_backend_tile_manager_get_tiles (backend);
}
-TempBuf *
+GimpTempBuf *
gimp_gegl_buffer_get_temp_buf (GeglBuffer *buffer)
{
g_return_val_if_fail (GEGL_IS_BUFFER (buffer), NULL);
diff --git a/app/gegl/gimp-gegl-utils.h b/app/gegl/gimp-gegl-utils.h
index eb05728..0b2bf67 100644
--- a/app/gegl/gimp-gegl-utils.h
+++ b/app/gegl/gimp-gegl-utils.h
@@ -41,7 +41,7 @@ GeglBuffer * gimp_tile_manager_create_buffer (TileManager *tm,
const Babl *format);
TileManager * gimp_gegl_buffer_get_tiles (GeglBuffer *buffer);
-TempBuf * gimp_gegl_buffer_get_temp_buf (GeglBuffer *buffer);
+GimpTempBuf * gimp_gegl_buffer_get_temp_buf (GeglBuffer *buffer);
GeglBuffer * gimp_pixbuf_create_buffer (GdkPixbuf *pixbuf);
diff --git a/app/paint/gimpbrushcore.c b/app/paint/gimpbrushcore.c
index 5b11eea..7b5ac01 100644
--- a/app/paint/gimpbrushcore.c
+++ b/app/paint/gimpbrushcore.c
@@ -92,38 +92,43 @@ static void gimp_brush_core_real_set_brush (GimpBrushCore *core,
static void gimp_brush_core_real_set_dynamics (GimpBrushCore *core,
GimpDynamics *dynamics);
-static const TempBuf * gimp_brush_core_subsample_mask (GimpBrushCore *core,
- const TempBuf *mask,
- gdouble x,
- gdouble y);
-static const TempBuf * gimp_brush_core_pressurize_mask (GimpBrushCore *core,
- const TempBuf *brush_mask,
- gdouble x,
- gdouble y,
- gdouble pressure);
-static const TempBuf * gimp_brush_core_solidify_mask (GimpBrushCore *core,
- const TempBuf *brush_mask,
- gdouble x,
- gdouble y);
-static const TempBuf * gimp_brush_core_transform_mask (GimpBrushCore *core,
- GimpBrush *brush);
-static const TempBuf * gimp_brush_core_transform_pixmap (GimpBrushCore *core,
- GimpBrush *brush);
-
-static void gimp_brush_core_invalidate_cache (GimpBrush *brush,
- GimpBrushCore *core);
+static const GimpTempBuf *
+ gimp_brush_core_subsample_mask (GimpBrushCore *core,
+ const GimpTempBuf *mask,
+ gdouble x,
+ gdouble y);
+static const GimpTempBuf *
+ gimp_brush_core_pressurize_mask (GimpBrushCore *core,
+ const GimpTempBuf *brush_mask,
+ gdouble x,
+ gdouble y,
+ gdouble pressure);
+static const GimpTempBuf *
+ gimp_brush_core_solidify_mask (GimpBrushCore *core,
+ const GimpTempBuf *brush_mask,
+ gdouble x,
+ gdouble y);
+static const GimpTempBuf *
+ gimp_brush_core_transform_mask (GimpBrushCore *core,
+ GimpBrush *brush);
+static const GimpTempBuf *
+ gimp_brush_core_transform_pixmap (GimpBrushCore *core,
+ GimpBrush *brush);
+
+static void gimp_brush_core_invalidate_cache (GimpBrush *brush,
+ GimpBrushCore *core);
/* brush pipe utility functions */
-static void gimp_brush_core_paint_line_pixmap_mask (GimpImage *dest,
- GimpDrawable *drawable,
- const TempBuf *pixmap_mask,
- const TempBuf *brush_mask,
- guchar *d,
- gint x,
- gint y,
- gint bytes,
- gint width,
- GimpBrushApplicationMode mode);
+static void gimp_brush_core_paint_line_pixmap_mask (GimpImage *dest,
+ GimpDrawable *drawable,
+ const GimpTempBuf *pixmap_mask,
+ const GimpTempBuf *brush_mask,
+ guchar *d,
+ gint x,
+ gint y,
+ gint bytes,
+ gint width,
+ GimpBrushApplicationMode mode);
G_DEFINE_TYPE (GimpBrushCore, gimp_brush_core, GIMP_TYPE_PAINT_CORE)
@@ -827,8 +832,8 @@ gimp_brush_core_get_paint_buffer (GimpPaintCore *paint_core,
/* configure the canvas buffer */
if ((x2 - x1) && (y2 - y1))
{
- const Babl *format = gimp_drawable_get_format_with_alpha (drawable);
- TempBuf *temp_buf;
+ const Babl *format = gimp_drawable_get_format_with_alpha (drawable);
+ GimpTempBuf *temp_buf;
temp_buf = temp_buf_new ((x2 - x1), (y2 - y1), format);
@@ -924,10 +929,11 @@ gimp_brush_core_paste_canvas (GimpBrushCore *core,
gdouble dynamic_force,
GimpPaintApplicationMode mode)
{
- const TempBuf *brush_mask = gimp_brush_core_get_brush_mask (core,
- coords,
- brush_hardness,
- dynamic_force);
+ const GimpTempBuf *brush_mask;
+
+ brush_mask = gimp_brush_core_get_brush_mask (core, coords,
+ brush_hardness,
+ dynamic_force);
if (brush_mask)
{
@@ -944,7 +950,7 @@ gimp_brush_core_paste_canvas (GimpBrushCore *core,
off_x = (x < 0) ? -x : 0;
off_y = (y < 0) ? -y : 0;
- paint_mask = gimp_temp_buf_create_buffer ((TempBuf *) brush_mask, FALSE);
+ paint_mask = gimp_temp_buf_create_buffer ((GimpTempBuf *) brush_mask, FALSE);
gimp_paint_core_paste (paint_core, paint_mask,
GEGL_RECTANGLE (off_x, off_y,
@@ -973,10 +979,11 @@ gimp_brush_core_replace_canvas (GimpBrushCore *core,
gdouble dynamic_force,
GimpPaintApplicationMode mode)
{
- const TempBuf *brush_mask = gimp_brush_core_get_brush_mask (core,
- coords,
- brush_hardness,
- dynamic_force);
+ const GimpTempBuf *brush_mask;
+
+ brush_mask = gimp_brush_core_get_brush_mask (core, coords,
+ brush_hardness,
+ dynamic_force);
if (brush_mask)
{
@@ -993,7 +1000,7 @@ gimp_brush_core_replace_canvas (GimpBrushCore *core,
off_x = (x < 0) ? -x : 0;
off_y = (y < 0) ? -y : 0;
- paint_mask = gimp_temp_buf_create_buffer ((TempBuf *) brush_mask, FALSE);
+ paint_mask = gimp_temp_buf_create_buffer ((GimpTempBuf *) brush_mask, FALSE);
gimp_paint_core_replace (paint_core, paint_mask,
GEGL_RECTANGLE (off_x, off_y,
@@ -1041,13 +1048,13 @@ rotate_pointers (gulong **p,
p[i] = tmp;
}
-static const TempBuf *
-gimp_brush_core_subsample_mask (GimpBrushCore *core,
- const TempBuf *mask,
- gdouble x,
- gdouble y)
+static const GimpTempBuf *
+gimp_brush_core_subsample_mask (GimpBrushCore *core,
+ const GimpTempBuf *mask,
+ gdouble x,
+ gdouble y)
{
- TempBuf *dest;
+ GimpTempBuf *dest;
gdouble left;
const guchar *m;
guchar *d;
@@ -1176,18 +1183,18 @@ gimp_brush_core_subsample_mask (GimpBrushCore *core,
/* #define FANCY_PRESSURE */
-static const TempBuf *
-gimp_brush_core_pressurize_mask (GimpBrushCore *core,
- const TempBuf *brush_mask,
- gdouble x,
- gdouble y,
- gdouble pressure)
+static const GimpTempBuf *
+gimp_brush_core_pressurize_mask (GimpBrushCore *core,
+ const GimpTempBuf *brush_mask,
+ gdouble x,
+ gdouble y,
+ gdouble pressure)
{
- static guchar mapi[256];
- const guchar *source;
- guchar *dest;
- const TempBuf *subsample_mask;
- gint i;
+ static guchar mapi[256];
+ const guchar *source;
+ guchar *dest;
+ const GimpTempBuf *subsample_mask;
+ gint i;
/* Get the raw subsampled mask */
subsample_mask = gimp_brush_core_subsample_mask (core,
@@ -1291,13 +1298,13 @@ gimp_brush_core_pressurize_mask (GimpBrushCore *core,
return core->pressure_brush;
}
-static const TempBuf *
-gimp_brush_core_solidify_mask (GimpBrushCore *core,
- const TempBuf *brush_mask,
- gdouble x,
- gdouble y)
+static const GimpTempBuf *
+gimp_brush_core_solidify_mask (GimpBrushCore *core,
+ const GimpTempBuf *brush_mask,
+ gdouble x,
+ gdouble y)
{
- TempBuf *dest;
+ GimpTempBuf *dest;
const guchar *m;
guchar *d;
gint dest_offset_x = 0;
@@ -1365,11 +1372,11 @@ gimp_brush_core_solidify_mask (GimpBrushCore *core,
return dest;
}
-static const TempBuf *
+static const GimpTempBuf *
gimp_brush_core_transform_mask (GimpBrushCore *core,
GimpBrush *brush)
{
- const TempBuf *mask;
+ const GimpTempBuf *mask;
if (core->scale <= 0.0)
return NULL;
@@ -1390,11 +1397,11 @@ gimp_brush_core_transform_mask (GimpBrushCore *core,
return core->transform_brush;
}
-static const TempBuf *
+static const GimpTempBuf *
gimp_brush_core_transform_pixmap (GimpBrushCore *core,
GimpBrush *brush)
{
- const TempBuf *pixmap;
+ const GimpTempBuf *pixmap;
if (core->scale <= 0.0)
return NULL;
@@ -1414,13 +1421,13 @@ gimp_brush_core_transform_pixmap (GimpBrushCore *core,
return core->transform_pixmap;
}
-const TempBuf *
+const GimpTempBuf *
gimp_brush_core_get_brush_mask (GimpBrushCore *core,
const GimpCoords *coords,
GimpBrushApplicationMode brush_hardness,
gdouble dynamic_force)
{
- const TempBuf *mask;
+ const GimpTempBuf *mask;
mask = gimp_brush_core_transform_mask (core, core->brush);
@@ -1537,22 +1544,22 @@ void
gimp_brush_core_color_area_with_pixmap (GimpBrushCore *core,
GimpDrawable *drawable,
const GimpCoords *coords,
- TempBuf *area,
+ GimpTempBuf *area,
gint area_x,
gint area_y,
GimpBrushApplicationMode mode)
{
- GimpImage *image;
- PixelRegion destPR;
- void *pr;
- guchar *d;
- gint ulx;
- gint uly;
- gint offsetx;
- gint offsety;
- gint y;
- const TempBuf *pixmap_mask;
- const TempBuf *brush_mask;
+ GimpImage *image;
+ PixelRegion destPR;
+ void *pr;
+ guchar *d;
+ gint ulx;
+ gint uly;
+ gint offsetx;
+ gint offsety;
+ gint y;
+ const GimpTempBuf *pixmap_mask;
+ const GimpTempBuf *brush_mask;
g_return_if_fail (GIMP_IS_BRUSH (core->brush));
g_return_if_fail (core->brush->pixmap != NULL);
@@ -1610,8 +1617,8 @@ gimp_brush_core_color_area_with_pixmap (GimpBrushCore *core,
static void
gimp_brush_core_paint_line_pixmap_mask (GimpImage *dest,
GimpDrawable *drawable,
- const TempBuf *pixmap_mask,
- const TempBuf *brush_mask,
+ const GimpTempBuf *pixmap_mask,
+ const GimpTempBuf *brush_mask,
guchar *d,
gint x,
gint y,
diff --git a/app/paint/gimpbrushcore.h b/app/paint/gimpbrushcore.h
index ba24d65..ef7008d 100644
--- a/app/paint/gimpbrushcore.h
+++ b/app/paint/gimpbrushcore.h
@@ -39,36 +39,36 @@ typedef struct _GimpBrushCoreClass GimpBrushCoreClass;
struct _GimpBrushCore
{
- GimpPaintCore parent_instance;
+ GimpPaintCore parent_instance;
- GimpBrush *main_brush;
- GimpBrush *brush;
- GimpDynamics *dynamics;
- gdouble spacing;
- gdouble scale;
- gdouble angle;
- gdouble hardness;
- gdouble aspect_ratio;
+ GimpBrush *main_brush;
+ GimpBrush *brush;
+ GimpDynamics *dynamics;
+ gdouble spacing;
+ gdouble scale;
+ gdouble angle;
+ gdouble hardness;
+ gdouble aspect_ratio;
/* brush buffers */
- TempBuf *pressure_brush;
+ GimpTempBuf *pressure_brush;
- TempBuf *solid_brushes[BRUSH_CORE_SOLID_SUBSAMPLE][BRUSH_CORE_SOLID_SUBSAMPLE];
- const TempBuf *last_solid_brush_mask;
- gboolean solid_cache_invalid;
+ GimpTempBuf *solid_brushes[BRUSH_CORE_SOLID_SUBSAMPLE][BRUSH_CORE_SOLID_SUBSAMPLE];
+ const GimpTempBuf *last_solid_brush_mask;
+ gboolean solid_cache_invalid;
- const TempBuf *transform_brush;
- const TempBuf *transform_pixmap;
+ const GimpTempBuf *transform_brush;
+ const GimpTempBuf *transform_pixmap;
- TempBuf *subsample_brushes[BRUSH_CORE_SUBSAMPLE + 1][BRUSH_CORE_SUBSAMPLE + 1];
- const TempBuf *last_subsample_brush_mask;
- gboolean subsample_cache_invalid;
+ GimpTempBuf *subsample_brushes[BRUSH_CORE_SUBSAMPLE + 1][BRUSH_CORE_SUBSAMPLE + 1];
+ const GimpTempBuf *last_subsample_brush_mask;
+ gboolean subsample_cache_invalid;
- gdouble jitter;
- gdouble jitter_lut_x[BRUSH_CORE_JITTER_LUTSIZE];
- gdouble jitter_lut_y[BRUSH_CORE_JITTER_LUTSIZE];
+ gdouble jitter;
+ gdouble jitter_lut_x[BRUSH_CORE_JITTER_LUTSIZE];
+ gdouble jitter_lut_y[BRUSH_CORE_JITTER_LUTSIZE];
- GRand *rand;
+ GRand *rand;
};
struct _GimpBrushCoreClass
@@ -121,12 +121,12 @@ void gimp_brush_core_color_area_with_pixmap
(GimpBrushCore *core,
GimpDrawable *drawable,
const GimpCoords *coords,
- TempBuf *area,
+ GimpTempBuf *area,
gint area_x,
gint area_y,
GimpBrushApplicationMode mode);
-const TempBuf * gimp_brush_core_get_brush_mask
+const GimpTempBuf * gimp_brush_core_get_brush_mask
(GimpBrushCore *core,
const GimpCoords *coords,
GimpBrushApplicationMode brush_hardness,
diff --git a/app/paint/gimpconvolve.c b/app/paint/gimpconvolve.c
index 43cfd98..50da2f2 100644
--- a/app/paint/gimpconvolve.c
+++ b/app/paint/gimpconvolve.c
@@ -136,7 +136,7 @@ gimp_convolve_motion (GimpPaintCore *paint_core,
GeglBuffer *paint_buffer;
gint paint_buffer_x;
gint paint_buffer_y;
- TempBuf *convolve_temp;
+ GimpTempBuf *convolve_temp;
GeglBuffer *convolve_buffer;
gdouble fade_point;
gdouble opacity;
diff --git a/app/paint/gimpheal.c b/app/paint/gimpheal.c
index f2c05ca..d3430dc 100644
--- a/app/paint/gimpheal.c
+++ b/app/paint/gimpheal.c
@@ -483,7 +483,7 @@ gimp_heal_motion (GimpSourceCore *source_core,
GimpImage *image = gimp_item_get_image (GIMP_ITEM (drawable));
GeglBuffer *src_copy;
GeglBuffer *mask_buffer;
- const TempBuf *mask_buf;
+ const GimpTempBuf *mask_buf;
gdouble fade_point;
gdouble hardness;
@@ -537,7 +537,7 @@ gimp_heal_motion (GimpSourceCore *source_core,
paint_area_width,
paint_area_height));
- mask_buffer = gimp_temp_buf_create_buffer ((TempBuf *) mask_buf, FALSE);
+ mask_buffer = gimp_temp_buf_create_buffer ((GimpTempBuf *) mask_buf, FALSE);
gimp_heal (src_copy,
GEGL_RECTANGLE (0, 0,
diff --git a/app/paint/gimpink.c b/app/paint/gimpink.c
index bd24019..da83274 100644
--- a/app/paint/gimpink.c
+++ b/app/paint/gimpink.c
@@ -220,8 +220,8 @@ gimp_ink_get_paint_buffer (GimpPaintCore *paint_core,
/* configure the canvas buffer */
if ((x2 - x1) && (y2 - y1))
{
- const Babl *format = gimp_drawable_get_format_with_alpha (drawable);
- TempBuf *temp_buf;
+ const Babl *format = gimp_drawable_get_format_with_alpha (drawable);
+ GimpTempBuf *temp_buf;
temp_buf = temp_buf_new ((x2 - x1), (y2 - y1), format);
diff --git a/app/paint/gimppaintbrush.c b/app/paint/gimppaintbrush.c
index a4a07a3..636fc3b 100644
--- a/app/paint/gimppaintbrush.c
+++ b/app/paint/gimppaintbrush.c
@@ -180,7 +180,7 @@ _gimp_paintbrush_motion (GimpPaintCore *paint_core,
/* otherwise check if the brush has a pixmap and use that to
* color the area
*/
- TempBuf *area = gimp_gegl_buffer_get_temp_buf (paint_buffer);
+ GimpTempBuf *area = gimp_gegl_buffer_get_temp_buf (paint_buffer);
gimp_brush_core_color_area_with_pixmap (brush_core, drawable,
coords,
diff --git a/app/paint/gimpsmudge.c b/app/paint/gimpsmudge.c
index b05368c..8b14422 100644
--- a/app/paint/gimpsmudge.c
+++ b/app/paint/gimpsmudge.c
@@ -164,13 +164,13 @@ gimp_smudge_start (GimpPaintCore *paint_core,
GimpPaintOptions *paint_options,
const GimpCoords *coords)
{
- GimpSmudge *smudge = GIMP_SMUDGE (paint_core);
- GeglBuffer *paint_buffer;
- gint paint_buffer_x;
- gint paint_buffer_y;
- TempBuf *accum_temp;
- gint accum_size;
- gint x, y;
+ GimpSmudge *smudge = GIMP_SMUDGE (paint_core);
+ GeglBuffer *paint_buffer;
+ gint paint_buffer_x;
+ gint paint_buffer_y;
+ GimpTempBuf *accum_temp;
+ gint accum_size;
+ gint x, y;
if (gimp_drawable_is_indexed (drawable))
return FALSE;
diff --git a/app/pdb/drawable-cmds.c b/app/pdb/drawable-cmds.c
index c5af490..9c759f5 100644
--- a/app/pdb/drawable-cmds.c
+++ b/app/pdb/drawable-cmds.c
@@ -719,9 +719,9 @@ drawable_thumbnail_invoker (GimpProcedure *procedure,
if (success)
{
- GimpImage *image = gimp_item_get_image (GIMP_ITEM (drawable));
- TempBuf *buf;
- gint dwidth, dheight;
+ GimpImage *image = gimp_item_get_image (GIMP_ITEM (drawable));
+ GimpTempBuf *buf;
+ gint dwidth, dheight;
g_assert (GIMP_VIEWABLE_MAX_PREVIEW_SIZE >= 1024);
@@ -809,8 +809,8 @@ drawable_sub_thumbnail_invoker (GimpProcedure *procedure,
if ((src_x + src_width) <= gimp_item_get_width (GIMP_ITEM (drawable)) &&
(src_y + src_height) <= gimp_item_get_height (GIMP_ITEM (drawable)))
{
- GimpImage *image = gimp_item_get_image (GIMP_ITEM (drawable));
- TempBuf *buf;
+ GimpImage *image = gimp_item_get_image (GIMP_ITEM (drawable));
+ GimpTempBuf *buf;
if (image->gimp->config->layer_previews)
buf = gimp_drawable_get_sub_preview (drawable,
diff --git a/app/pdb/image-cmds.c b/app/pdb/image-cmds.c
index 5b91435..7c859e4 100644
--- a/app/pdb/image-cmds.c
+++ b/app/pdb/image-cmds.c
@@ -1691,8 +1691,8 @@ image_thumbnail_invoker (GimpProcedure *procedure,
if (success)
{
- TempBuf *buf;
- gint dwidth, dheight;
+ GimpTempBuf *buf;
+ gint dwidth, dheight;
g_assert (GIMP_VIEWABLE_MAX_PREVIEW_SIZE >= 1024);
diff --git a/app/text/gimpfont.c b/app/text/gimpfont.c
index 9ee002f..42a351e 100644
--- a/app/text/gimpfont.c
+++ b/app/text/gimpfont.c
@@ -70,28 +70,28 @@ struct _GimpFontClass
};
-static void gimp_font_finalize (GObject *object);
-static void gimp_font_set_property (GObject *object,
- guint property_id,
- const GValue *value,
- GParamSpec *pspec);
-
-static void gimp_font_get_preview_size (GimpViewable *viewable,
- gint size,
- gboolean popup,
- gboolean dot_for_dot,
- gint *width,
- gint *height);
-static gboolean gimp_font_get_popup_size (GimpViewable *viewable,
- gint width,
- gint height,
- gboolean dot_for_dot,
- gint *popup_width,
- gint *popup_height);
-static TempBuf * gimp_font_get_new_preview (GimpViewable *viewable,
- GimpContext *context,
- gint width,
- gint height);
+static void gimp_font_finalize (GObject *object);
+static void gimp_font_set_property (GObject *object,
+ guint property_id,
+ const GValue *value,
+ GParamSpec *pspec);
+
+static void gimp_font_get_preview_size (GimpViewable *viewable,
+ gint size,
+ gboolean popup,
+ gboolean dot_for_dot,
+ gint *width,
+ gint *height);
+static gboolean gimp_font_get_popup_size (GimpViewable *viewable,
+ gint width,
+ gint height,
+ gboolean dot_for_dot,
+ gint *popup_width,
+ gint *popup_height);
+static GimpTempBuf * gimp_font_get_new_preview (GimpViewable *viewable,
+ GimpContext *context,
+ gint width,
+ gint height);
static const gchar * gimp_font_get_sample_string (PangoContext *context,
PangoFontDescription *font_desc);
@@ -229,7 +229,7 @@ gimp_font_get_popup_size (GimpViewable *viewable,
return TRUE;
}
-static TempBuf *
+static GimpTempBuf *
gimp_font_get_new_preview (GimpViewable *viewable,
GimpContext *context,
gint width,
@@ -243,7 +243,7 @@ gimp_font_get_new_preview (GimpViewable *viewable,
gint layout_height;
gint layout_x;
gint layout_y;
- TempBuf *temp_buf;
+ GimpTempBuf *temp_buf;
cairo_t *cr;
cairo_surface_t *surface;
diff --git a/app/tools/gimpiscissorstool.c b/app/tools/gimpiscissorstool.c
index 1a0c7f0..b8e27e0 100644
--- a/app/tools/gimpiscissorstool.c
+++ b/app/tools/gimpiscissorstool.c
@@ -158,7 +158,7 @@ static void iscissors_convert (GimpIscissorsTool *iscissors,
static TileManager * gradient_map_new (GimpImage *image);
static void find_optimal_path (TileManager *gradient_map,
- TempBuf *dp_buf,
+ GimpTempBuf *dp_buf,
gint x1,
gint y1,
gint x2,
@@ -188,7 +188,7 @@ static gboolean clicked_on_curve (GimpIscissorsTool *iscissors,
gdouble y);
static GPtrArray * plot_pixels (GimpIscissorsTool *iscissors,
- TempBuf *dp_buf,
+ GimpTempBuf *dp_buf,
gint x1,
gint y1,
gint xs,
@@ -1458,7 +1458,7 @@ calculate_link (TileManager *gradient_map,
static GPtrArray *
plot_pixels (GimpIscissorsTool *iscissors,
- TempBuf *dp_buf,
+ GimpTempBuf *dp_buf,
gint x1,
gint y1,
gint xs,
@@ -1509,7 +1509,7 @@ plot_pixels (GimpIscissorsTool *iscissors,
static void
find_optimal_path (TileManager *gradient_map,
- TempBuf *dp_buf,
+ GimpTempBuf *dp_buf,
gint x1,
gint y1,
gint x2,
diff --git a/app/tools/gimpiscissorstool.h b/app/tools/gimpiscissorstool.h
index 21b56a8..36a26ba 100644
--- a/app/tools/gimpiscissorstool.h
+++ b/app/tools/gimpiscissorstool.h
@@ -68,7 +68,7 @@ struct _GimpIscissorsTool
gint ix, iy; /* initial coordinates */
gint nx, ny; /* new coordinates */
- TempBuf *dp_buf; /* dynamic programming buffer */
+ GimpTempBuf *dp_buf; /* dynamic programming buffer */
ICurve *livewire; /* livewire boundary curve */
diff --git a/app/vectors/gimpvectors-preview.c b/app/vectors/gimpvectors-preview.c
index 259b3a0..98212fe 100644
--- a/app/vectors/gimpvectors-preview.c
+++ b/app/vectors/gimpvectors-preview.c
@@ -36,7 +36,7 @@
/* public functions */
-TempBuf *
+GimpTempBuf *
gimp_vectors_get_new_preview (GimpViewable *viewable,
GimpContext *context,
gint width,
@@ -47,7 +47,7 @@ gimp_vectors_get_new_preview (GimpViewable *viewable,
GimpStroke *cur_stroke;
gdouble xscale, yscale;
guchar *data;
- TempBuf *temp_buf;
+ GimpTempBuf *temp_buf;
vectors = GIMP_VECTORS (viewable);
item = GIMP_ITEM (viewable);
diff --git a/app/vectors/gimpvectors-preview.h b/app/vectors/gimpvectors-preview.h
index d30f6d5..23ba3af 100644
--- a/app/vectors/gimpvectors-preview.h
+++ b/app/vectors/gimpvectors-preview.h
@@ -23,10 +23,10 @@
* virtual function of GimpVectors -- dont't call directly
*/
-TempBuf * gimp_vectors_get_new_preview (GimpViewable *viewable,
- GimpContext *context,
- gint width,
- gint height);
+GimpTempBuf * gimp_vectors_get_new_preview (GimpViewable *viewable,
+ GimpContext *context,
+ gint width,
+ gint height);
#endif /* __GIMP_VECTORS_PREVIEW_H__ */
diff --git a/app/widgets/gimpviewrenderer.c b/app/widgets/gimpviewrenderer.c
index 031f392..69dc3ec 100644
--- a/app/widgets/gimpviewrenderer.c
+++ b/app/widgets/gimpviewrenderer.c
@@ -74,7 +74,7 @@ static cairo_pattern_t *
gimp_view_renderer_create_background (GimpViewRenderer *renderer,
GtkWidget *widget);
-static void gimp_view_render_temp_buf_to_surface (TempBuf *temp_buf,
+static void gimp_view_render_temp_buf_to_surface (GimpTempBuf *temp_buf,
gint channel,
GimpViewBG inside_bg,
GimpViewBG outside_bg,
@@ -748,7 +748,7 @@ gimp_view_renderer_real_render (GimpViewRenderer *renderer,
GtkWidget *widget)
{
GdkPixbuf *pixbuf;
- TempBuf *temp_buf;
+ GimpTempBuf *temp_buf;
const gchar *stock_id;
pixbuf = gimp_viewable_get_pixbuf (renderer->viewable,
@@ -791,7 +791,7 @@ gimp_view_renderer_size_changed (GimpViewRenderer *renderer,
void
gimp_view_renderer_render_temp_buf_simple (GimpViewRenderer *renderer,
- TempBuf *temp_buf)
+ GimpTempBuf *temp_buf)
{
g_return_if_fail (GIMP_IS_VIEW_RENDERER (renderer));
g_return_if_fail (temp_buf != NULL);
@@ -809,7 +809,7 @@ gimp_view_renderer_render_temp_buf_simple (GimpViewRenderer *renderer,
void
gimp_view_renderer_render_temp_buf (GimpViewRenderer *renderer,
- TempBuf *temp_buf,
+ GimpTempBuf *temp_buf,
gint channel,
GimpViewBG inside_bg,
GimpViewBG outside_bg)
@@ -917,7 +917,7 @@ gimp_view_renderer_render_stock (GimpViewRenderer *renderer,
}
static void
-gimp_view_render_temp_buf_to_surface (TempBuf *temp_buf,
+gimp_view_render_temp_buf_to_surface (GimpTempBuf *temp_buf,
gint channel,
GimpViewBG inside_bg,
GimpViewBG outside_bg,
diff --git a/app/widgets/gimpviewrenderer.h b/app/widgets/gimpviewrenderer.h
index ac451eb..1a52edc 100644
--- a/app/widgets/gimpviewrenderer.h
+++ b/app/widgets/gimpviewrenderer.h
@@ -141,9 +141,9 @@ void gimp_view_renderer_draw (GimpViewRenderer *renderer,
/* protected */
void gimp_view_renderer_render_temp_buf_simple (GimpViewRenderer *renderer,
- TempBuf *temp_buf);
+ GimpTempBuf *temp_buf);
void gimp_view_renderer_render_temp_buf (GimpViewRenderer *renderer,
- TempBuf *temp_buf,
+ GimpTempBuf *temp_buf,
gint channel,
GimpViewBG inside_bg,
GimpViewBG outside_bg);
diff --git a/app/widgets/gimpviewrendererbrush.c b/app/widgets/gimpviewrendererbrush.c
index 27e5ef8..0624bae 100644
--- a/app/widgets/gimpviewrendererbrush.c
+++ b/app/widgets/gimpviewrendererbrush.c
@@ -89,7 +89,7 @@ gimp_view_renderer_brush_render (GimpViewRenderer *renderer,
GtkWidget *widget)
{
GimpViewRendererBrush *renderbrush = GIMP_VIEW_RENDERER_BRUSH (renderer);
- TempBuf *temp_buf;
+ GimpTempBuf *temp_buf;
if (renderbrush->pipe_timeout_id)
{
@@ -141,7 +141,7 @@ gimp_view_renderer_brush_render_timeout (gpointer data)
GimpViewRenderer *renderer = GIMP_VIEW_RENDERER (data);
GimpBrushPipe *brush_pipe;
GimpBrush *brush;
- TempBuf *temp_buf;
+ GimpTempBuf *temp_buf;
if (! renderer->viewable)
{
diff --git a/app/widgets/gimpviewrendererbuffer.c b/app/widgets/gimpviewrendererbuffer.c
index 961ccd7..f3a02d2 100644
--- a/app/widgets/gimpviewrendererbuffer.c
+++ b/app/widgets/gimpviewrendererbuffer.c
@@ -61,12 +61,12 @@ static void
gimp_view_renderer_buffer_render (GimpViewRenderer *renderer,
GtkWidget *widget)
{
- gint buffer_width;
- gint buffer_height;
- gint view_width;
- gint view_height;
- gboolean scaling_up;
- TempBuf *render_buf = NULL;
+ gint buffer_width;
+ gint buffer_height;
+ gint view_width;
+ gint view_height;
+ gboolean scaling_up;
+ GimpTempBuf *render_buf = NULL;
gimp_viewable_get_size (renderer->viewable, &buffer_width, &buffer_height);
@@ -81,7 +81,7 @@ gimp_view_renderer_buffer_render (GimpViewRenderer *renderer,
if (scaling_up)
{
- TempBuf *temp_buf;
+ GimpTempBuf *temp_buf;
temp_buf = gimp_viewable_get_new_preview (renderer->viewable,
renderer->context,
diff --git a/app/widgets/gimpviewrendererdrawable.c b/app/widgets/gimpviewrendererdrawable.c
index 5d4423d..11f046f 100644
--- a/app/widgets/gimpviewrendererdrawable.c
+++ b/app/widgets/gimpviewrendererdrawable.c
@@ -78,7 +78,7 @@ gimp_view_renderer_drawable_render (GimpViewRenderer *renderer,
gdouble xres = 1.0;
gdouble yres = 1.0;
gboolean scaling_up;
- TempBuf *render_buf = NULL;
+ GimpTempBuf *render_buf = NULL;
drawable = GIMP_DRAWABLE (renderer->viewable);
item = GIMP_ITEM (drawable);
@@ -175,7 +175,7 @@ gimp_view_renderer_drawable_render (GimpViewRenderer *renderer,
}
else
{
- TempBuf *temp_buf;
+ GimpTempBuf *temp_buf;
temp_buf = gimp_viewable_get_new_preview (renderer->viewable,
renderer->context,
diff --git a/app/widgets/gimpviewrendererimage.c b/app/widgets/gimpviewrendererimage.c
index 24bb098..598cef1 100644
--- a/app/widgets/gimpviewrendererimage.c
+++ b/app/widgets/gimpviewrendererimage.c
@@ -75,12 +75,12 @@ gimp_view_renderer_image_render (GimpViewRenderer *renderer,
(gimp_image_get_component_visible (image, rendererimage->channel) &&
gimp_image_get_component_visible (image, GIMP_ALPHA_CHANNEL)))
{
- gint view_width;
- gint view_height;
- gdouble xres;
- gdouble yres;
- gboolean scaling_up;
- TempBuf *render_buf = NULL;
+ gint view_width;
+ gint view_height;
+ gdouble xres;
+ gdouble yres;
+ gboolean scaling_up;
+ GimpTempBuf *render_buf = NULL;
gimp_image_get_resolution (image, &xres, &yres);
@@ -97,7 +97,7 @@ gimp_view_renderer_image_render (GimpViewRenderer *renderer,
if (scaling_up)
{
- TempBuf *temp_buf;
+ GimpTempBuf *temp_buf;
temp_buf = gimp_viewable_get_new_preview (renderer->viewable,
renderer->context,
@@ -126,7 +126,7 @@ gimp_view_renderer_image_render (GimpViewRenderer *renderer,
/* xresolution != yresolution */
if (view_width > renderer->width || view_height > renderer->height)
{
- TempBuf *temp_buf;
+ GimpTempBuf *temp_buf;
temp_buf = temp_buf_scale (render_buf,
renderer->width, renderer->height);
diff --git a/tools/pdbgen/pdb/drawable.pdb b/tools/pdbgen/pdb/drawable.pdb
index 984017d..0703476 100644
--- a/tools/pdbgen/pdb/drawable.pdb
+++ b/tools/pdbgen/pdb/drawable.pdb
@@ -703,9 +703,9 @@ HELP
%invoke = (
code => <<'CODE'
{
- GimpImage *image = gimp_item_get_image (GIMP_ITEM (drawable));
- TempBuf *buf;
- gint dwidth, dheight;
+ GimpImage *image = gimp_item_get_image (GIMP_ITEM (drawable));
+ GimpTempBuf *buf;
+ gint dwidth, dheight;
g_assert (GIMP_VIEWABLE_MAX_PREVIEW_SIZE >= 1024);
@@ -794,8 +794,8 @@ HELP
if ((src_x + src_width) <= gimp_item_get_width (GIMP_ITEM (drawable)) &&
(src_y + src_height) <= gimp_item_get_height (GIMP_ITEM (drawable)))
{
- GimpImage *image = gimp_item_get_image (GIMP_ITEM (drawable));
- TempBuf *buf;
+ GimpImage *image = gimp_item_get_image (GIMP_ITEM (drawable));
+ GimpTempBuf *buf;
if (image->gimp->config->layer_previews)
buf = gimp_drawable_get_sub_preview (drawable,
diff --git a/tools/pdbgen/pdb/image.pdb b/tools/pdbgen/pdb/image.pdb
index 0b4fb7f..81b324e 100644
--- a/tools/pdbgen/pdb/image.pdb
+++ b/tools/pdbgen/pdb/image.pdb
@@ -2839,8 +2839,8 @@ HELP
%invoke = (
code => <<'CODE'
{
- TempBuf *buf;
- gint dwidth, dheight;
+ GimpTempBuf *buf;
+ gint dwidth, dheight;
g_assert (GIMP_VIEWABLE_MAX_PREVIEW_SIZE >= 1024);
[
Date Prev][
Date Next] [
Thread Prev][
Thread Next]
[
Thread Index]
[
Date Index]
[
Author Index]
diff --git a/app/base/temp-buf.c b/app/base/temp-buf.c
index 98ce366..823ca44 100644
--- a/app/base/temp-buf.c
+++ b/app/base/temp-buf.c
@@ -32,17 +32,17 @@
#include "temp-buf.h"
-TempBuf *
+GimpTempBuf *
temp_buf_new (gint width,
gint height,
const Babl *format)
{
- TempBuf *temp;
+ GimpTempBuf *temp;
g_return_val_if_fail (width > 0 && height > 0, NULL);
g_return_val_if_fail (format != NULL, NULL);
- temp = g_slice_new (TempBuf);
+ temp = g_slice_new (GimpTempBuf);
temp->format = format;
temp->width = width;
@@ -57,10 +57,10 @@ temp_buf_new (gint width,
return temp;
}
-TempBuf *
-temp_buf_copy (TempBuf *src)
+GimpTempBuf *
+temp_buf_copy (GimpTempBuf *src)
{
- TempBuf *dest;
+ GimpTempBuf *dest;
g_return_val_if_fail (src != NULL, NULL);
@@ -76,12 +76,12 @@ temp_buf_copy (TempBuf *src)
return dest;
}
-TempBuf *
-temp_buf_scale (TempBuf *src,
- gint new_width,
- gint new_height)
+GimpTempBuf *
+temp_buf_scale (GimpTempBuf *src,
+ gint new_width,
+ gint new_height)
{
- TempBuf *dest;
+ GimpTempBuf *dest;
const guchar *src_data;
guchar *dest_data;
gdouble x_ratio;
@@ -132,10 +132,10 @@ temp_buf_scale (TempBuf *src,
* temp_buf_demultiply:
* @buf:
*
* Converts a TempBuf with pre-multiplied alpha to a 'normal' TempBuf.
*/
void
-temp_buf_demultiply (TempBuf *buf)
+temp_buf_demultiply (GimpTempBuf *buf)
{
guchar *data;
gint pixels;
@@ -181,30 +181,30 @@ temp_buf_demultiply (TempBuf *buf)
}
void
-temp_buf_free (TempBuf *buf)
+temp_buf_free (GimpTempBuf *buf)
{
g_return_if_fail (buf != NULL);
if (buf->data)
g_free (buf->data);
- g_slice_free (TempBuf, buf);
+ g_slice_free (GimpTempBuf, buf);
}
guchar *
-temp_buf_get_data (const TempBuf *buf)
+temp_buf_get_data (const GimpTempBuf *buf)
{
return buf->data;
}
gsize
-temp_buf_get_data_size (TempBuf *buf)
+temp_buf_get_data_size (GimpTempBuf *buf)
{
return babl_format_get_bytes_per_pixel (buf->format) * buf->width * buf->height;
}
guchar *
-temp_buf_data_clear (TempBuf *buf)
+temp_buf_data_clear (GimpTempBuf *buf)
{
memset (buf->data, 0, temp_buf_get_data_size (buf));
@@ -212,10 +212,10 @@ temp_buf_data_clear (TempBuf *buf)
}
gsize
-temp_buf_get_memsize (TempBuf *buf)
+temp_buf_get_memsize (GimpTempBuf *buf)
{
if (buf)
- return (sizeof (TempBuf) + temp_buf_get_data_size (buf));
+ return (sizeof (GimpTempBuf) + temp_buf_get_data_size (buf));
return 0;
}
@@ -226,11 +226,11 @@ temp_buf_get_memsize (TempBuf *buf)
* @buf:
* @file:
*
* Dumps a TempBuf to a raw RGB image that is easy to analyze, for
* example with GIMP.
**/
void
-temp_buf_dump (TempBuf *buf,
+temp_buf_dump (GimpTempBuf *buf,
const gchar *filename)
{
gint fd = g_open (filename, O_CREAT | O_TRUNC | O_WRONLY, 0666);
@@ -245,8 +245,8 @@ temp_buf_dump (TempBuf *buf,
}
GeglBuffer *
-gimp_temp_buf_create_buffer (TempBuf *temp_buf,
- gboolean take_ownership)
+gimp_temp_buf_create_buffer (GimpTempBuf *temp_buf,
+ gboolean take_ownership)
{
GeglBuffer *buffer;
@@ -132,10 +132,10 @@ temp_buf_scale (TempBuf *src,
* @buf:
*
- * Converts a TempBuf with pre-multiplied alpha to a 'normal' TempBuf.
+ * Converts a GimpTempBuf with pre-multiplied alpha to a 'normal' GimpTempBuf.
*/
void
@@ -226,11 +226,11 @@ temp_buf_get_memsize (TempBuf *buf)
* @file:
*
- * Dumps a TempBuf to a raw RGB image that is easy to analyze, for
+ * Dumps a GimpTempBuf to a raw RGB image that is easy to analyze, for
* example with GIMP.
**/
diff --git a/app/core/gimpviewable.c b/app/core/gimpviewable.c
index 0f776c4..5d120f3 100644
--- a/app/core/gimpviewable.c
+++ b/app/core/gimpviewable.c
@@ -64,7 +64,7 @@ struct _GimpViewablePrivate
gint freeze_count;
GimpViewable *parent;
- TempBuf *preview_temp_buf;
+ GimpTempBuf *preview_temp_buf;
GdkPixbuf *preview_pixbuf;
};
@@ -348,8 +348,8 @@ gimp_viewable_real_get_new_pixbuf (GimpViewable *viewable,
gint width,
gint height)
{
- TempBuf *temp_buf;
- GdkPixbuf *pixbuf = NULL;
+ GimpTempBuf *temp_buf;
+ GdkPixbuf *pixbuf = NULL;
temp_buf = gimp_viewable_get_preview (viewable, context, width, height);
@@ -677,10 +677,10 @@ gimp_viewable_get_popup_size (GimpViewable *viewable,
* method, and executes it, caching the result. If everything fails,
* #NULL is returned.
*
* Returns: A #TempBuf containg the preview image, or #NULL if none can
* be found or created.
**/
-TempBuf *
+GimpTempBuf *
gimp_viewable_get_preview (GimpViewable *viewable,
GimpContext *context,
gint width,
@@ -688,7 +688,7 @@ gimp_viewable_get_preview (GimpViewable *viewable,
{
GimpViewablePrivate *private;
GimpViewableClass *viewable_class;
- TempBuf *temp_buf = NULL;
+ GimpTempBuf *temp_buf = NULL;
g_return_val_if_fail (GIMP_IS_VIEWABLE (viewable), NULL);
g_return_val_if_fail (context == NULL || GIMP_IS_CONTEXT (context), NULL);
@@ -741,17 +741,17 @@ gimp_viewable_get_preview (GimpViewable *viewable,
* then if that fails for a "get_preview" method. This function does
* not look for a cached preview.
*
* Returns: A #TempBuf containg the preview image, or #NULL if none can
* be found or created.
**/
-TempBuf *
+GimpTempBuf *
gimp_viewable_get_new_preview (GimpViewable *viewable,
GimpContext *context,
gint width,
gint height)
{
GimpViewableClass *viewable_class;
- TempBuf *temp_buf = NULL;
+ GimpTempBuf *temp_buf = NULL;
g_return_val_if_fail (GIMP_IS_VIEWABLE (viewable), NULL);
g_return_val_if_fail (context == NULL || GIMP_IS_CONTEXT (context), NULL);
@@ -792,18 +792,18 @@ gimp_viewable_get_new_preview (GimpViewable *viewable,
* generate a preview in situations where layer previews have been
* disabled in the current Gimp configuration.
*
* Returns: a #TempBuf containing the preview image.
**/
-TempBuf *
+GimpTempBuf *
gimp_viewable_get_dummy_preview (GimpViewable *viewable,
gint width,
gint height,
gint bpp)
{
- GdkPixbuf *pixbuf;
- TempBuf *buf;
- guchar *src;
- guchar *dest;
+ GdkPixbuf *pixbuf;
+ GimpTempBuf *buf;
+ guchar *src;
+ guchar *dest;
g_return_val_if_fail (GIMP_IS_VIEWABLE (viewable), NULL);
g_return_val_if_fail (width > 0, NULL);
@@ -677,10 +677,10 @@ gimp_viewable_get_popup_size (GimpViewable *viewable,
* #NULL is returned.
*
- * Returns: A #TempBuf containg the preview image, or #NULL if none can
- * be found or created.
+ * Returns: A #GimpTempBuf containg the preview image, or #NULL if
+ * none can be found or created.
**/
@@ -741,17 +741,17 @@ gimp_viewable_get_preview (GimpViewable *viewable,
* not look for a cached preview.
*
- * Returns: A #TempBuf containg the preview image, or #NULL if none can
- * be found or created.
+ * Returns: A #GimpTempBuf containg the preview image, or #NULL if
+ * none can be found or created.
**/
@@ -792,18 +792,18 @@ gimp_viewable_get_new_preview (GimpViewable *viewable,
* disabled in the current Gimp configuration.
*
- * Returns: a #TempBuf containing the preview image.
+ * Returns: a #GimpTempBuf containing the preview image.
**/